task

package
v0.0.0-...-e86b535 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 8, 2024 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package tasktree defines a tree of tasks.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Id

type Id string

type Priority

type Priority byte

A Priority represents how important it is for a Task to be completed.

const (
	// Default priority.
	Default Priority = iota
	// Urgent priority.
	Urgent
	// High priority.
	High
	// Normal priority.
	Normal
	// Low priority.
	Low
)

type Tag

type Tag string

A Tag is a searchable piece of information about a Task.

type Task

type Task struct {
	Id            Id
	Name          string
	Description   string
	EstimatedTime time.Duration
	TimeInvested  time.Duration
	Completed     bool
	Tags          []Tag
	Priority      Priority
}

A Task represents an individual task.

Jump to